@@ -30,11 +30,11 @@ __all__ = [
 ]
 
 from ._abc import IAdapter, IUniClient, IUniWebsocketManager
-from ._abc import IUniClient as IUniAsyncClient
-from ._abc import IUniWebsocketManager as IUniAsyncWebsocketManager
+from ._abc.asyncio import IUniClient as IUniAsyncClient
+from ._abc.asyncio import IUniWebsocketManager as IUniAsyncWebsocketManager
 from ._base import BaseClient, Websocket
-from ._base import BaseClient as BaseAsyncClient
-from ._base import Websocket as AsyncWebsocket
+from ._base.asyncio import BaseClient as BaseAsyncClient
+from ._base.asyncio import Websocket as AsyncWebsocket
 from .enums import Exchange, MarketType, Side, Timeframe
 from .mapper import get_uni_client, get_uni_websocket_manager
 from .types import AggTradeDict, KlineDict, LoggerLike, RequestMethod, TickerDailyDict, TradeDict
