@@ -1,7 +1,7 @@
 __all__ = ["WebsocketManager"]
 
 
-from collections.abc import Awaitable, Callable, Collection
+from collections.abc import Awaitable, Callable, Sequence
 from typing import Any
 
 from unicex._base.asyncio import Websocket
@@ -39,14 +39,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения сделок.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -64,14 +64,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения агрегированных сделок.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -90,7 +90,7 @@ class WebsocketManager(WebsocketManagerMixin):
         callback: CallbackType,
         interval: SpotTimeframe,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения свечей.
 
@@ -98,7 +98,7 @@ class WebsocketManager(WebsocketManagerMixin):
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
             interval (`SpotTimeframe`): Временной интервал свечей.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -116,14 +116,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения событий изменения стакана (без лимита глубины).
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -141,14 +141,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для мини‑статистики тикера за последние 24 часа.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -171,14 +171,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для расширенной статистики тикера за последние 24 часа.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -209,7 +209,7 @@ class WebsocketManager(WebsocketManagerMixin):
         callback: CallbackType,
         window: RollingWindowSize,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения статистики тикера за указанное окно времени.
 
@@ -217,7 +217,7 @@ class WebsocketManager(WebsocketManagerMixin):
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             window (`RollingWindowSize`): Размер окна статистики.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -240,14 +240,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения среднего прайса (Average Price).
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -265,14 +265,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения лучших бид/аск по символам.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -291,7 +291,7 @@ class WebsocketManager(WebsocketManagerMixin):
         callback: CallbackType,
         levels: BookDepthLevels,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения стакана глубиной N уровней.
 
@@ -299,7 +299,7 @@ class WebsocketManager(WebsocketManagerMixin):
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             levels (`BookDepthLevels`): Глубина стакана (уровни).
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -337,14 +337,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения сделок.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -362,14 +362,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения агрегированных сделок.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -388,7 +388,7 @@ class WebsocketManager(WebsocketManagerMixin):
         callback: CallbackType,
         interval: FuturesTimeframe,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения свечей.
 
@@ -396,7 +396,7 @@ class WebsocketManager(WebsocketManagerMixin):
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             interval (`FuturesTimeframe`): Временной интервал свечей.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -414,14 +414,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для мини‑статистики тикера за последние 24 часа.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -451,14 +451,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для расширенной статистики тикера за последние 24 часа.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -488,14 +488,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения лучших бид/аск по символам.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -514,7 +514,7 @@ class WebsocketManager(WebsocketManagerMixin):
         callback: CallbackType,
         symbol: str | None,
         levels: BookDepthLevels,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения стакана глубиной N уровней.
 
@@ -522,7 +522,7 @@ class WebsocketManager(WebsocketManagerMixin):
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
             levels (`BookDepthLevels`): Глубина стакана (уровни).
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -540,14 +540,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения событий изменения стакана (без лимита глубины).
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -585,7 +585,7 @@ class WebsocketManager(WebsocketManagerMixin):
         callback: CallbackType,
         interval: MarkPriceUpdateSpeed = "1s",
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения mark price и funding rate по символам.
 
@@ -593,7 +593,7 @@ class WebsocketManager(WebsocketManagerMixin):
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             interval (`MarkPriceUpdateSpeed`): Частота обновления ("1s" или пусто).
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -629,14 +629,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения ликвидационных ордеров по символам.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
@@ -659,14 +659,14 @@ class WebsocketManager(WebsocketManagerMixin):
         self,
         callback: CallbackType,
         symbol: str | None = None,
-        symbols: Collection[str] | None = None,
+        symbols: Sequence[str] | None = None,
     ) -> Websocket:
         """Создает вебсокет для получения информации по композитному индексу.
 
         Параметры:
             callback (`CallbackType`): Асинхронная функция обратного вызова для обработки сообщений.
             symbol (`str | None`): Один символ для подписки.
-            symbols (`Collection[str] | None`): Список символов для мультиплекс‑подключения.
+            symbols (`Sequence[str] | None`): Список символов для мультиплекс‑подключения.
 
         Возвращает:
             `Websocket`: Объект для управления вебсокет соединением.
